@@ -5,7 +5,7 @@
 #' @return Logical, `TRUE` if metric is custom and `FALSE` otherwise
 #' @noRd
 is_calculated_metric <- function(metric) {
-  grepl('cm*_*', metric)
+  grepl('cm[1-9]*_*', metric)
 }
 
 #' Make a component lookup table
